#!/usr/bin/env python
# vim:fileencoding=utf-8

from __future__ import unicode_literals
# We must import unicode_literals, so we can use the dict correctly.
# All the 'language names' on 'worker.py' are unicode.

__license__   = 'GPL v3'
__copyright__ = '2011, Rodrigo Coin Curvo. 2019, Thiago Oliveira'
__docformat__ = 'restructuredtext en'

# Most used languages (Portuguese to Dutch) were put first, out of order, for better performance.
iso_639_codes = {
    'Português': 'por',
    'Inglês': 'eng',
    'Espanhol': 'spa',
    'Francês': 'fra',
    'Alemão': 'deu',
    'Italiano': 'ita',
    'Holandês': 'nld',
    'Esperanto': 'epo',
    'Abecásio': 'abk',
    'Afar': 'aar',
    'Africâner': 'afr',
    'Akan': 'aka',
    'Albanês': 'sqi',
    'Amárico': 'amh',
    'Árabe': 'ara',
    'Aragonês': 'arg',
    'Armênio': 'hye',
    'Assamês': 'asm',
    'Ávar': 'ava',
    'Avéstico': 'ave',
    'Aymará': 'aym',
    'Azerbaijano': 'aze',
    'Bambara': 'bam',
    'Bashkir': 'bak',
    'Basco': 'eus',
    'Bielorrusso': 'bel',
    'Bengali': 'ben',
    'Bihari': 'bih',
    'Bislamá': 'bis',
    'Bósnio': 'bos',
    'Bretão': 'bre',
    'Búlgaro': 'bul',
    'Birmanês': 'mya',
    'Catalão': 'cat',
    'Chamorro': 'cha',
    'Checheno': 'che',
    'Chichewa': 'nya',
    'Chinês': 'zho',
    'Chuvash': 'chv',
    'Córnico': 'cor',
    'Córso': 'cos',
    'Cree': 'cre',
    'Croata': 'hrv',
    'Dinamarquês': 'dan',
    'Divehi': 'div',
    'Dzongkha': 'dzo',
    'Estoniano': 'est',
    'Ewe': 'ewe',
    'Faroês': 'fao',
    'Fijiano': 'fij',
    'Finlandês': 'fin',
    'Fula': 'ful',
    'Galego': 'glg',
    'Georgiano': 'kat',
    'Grego Moderno': 'ell',
    'Guarani': 'grn',
    'Guzerate': 'guj',
    'Crioulo haitiano': 'hat',
    'Hauçá': 'hau',
    'Hebraico': 'heb',
    'Herero': 'her',
    'Hindi': 'hin',
    'Hiri Motu': 'hmo',
    'Húngaro': 'hun',
    'Interlíngua': 'ina',
    'Indonésio': 'ind',
    'Interlingue': 'ile',
    'Irlandês': 'gle',
    'Igbo': 'ibo',
    'Inupiaq': 'ipk',
    'Ido': 'ido',
    'Islandês': 'isl',
    'Inuktitut': 'iku',
    'Japonês': 'jpn',
    'Javanês': 'jav',
    'Kalaallisut': 'kal',
    'Canará': 'kan',
    'Kanuri': 'kau',
    'Caxemira': 'kas',
    'Cazaque': 'kaz',
    'Khmer': 'khm',
    'Kikuyu': 'kik',
    'Kinyarwanda': 'kin',
    'Quirguiz': 'kir',
    'Komi': 'kom',
    'Congolês': 'kon',
    'Coreano': 'kor',
    'Curdo': 'kur',
    'Kwanyama, Cuanhama': 'kua',
    'Latim': 'lat',
    'Luxemburguês': 'ltz',
    'Luganda': 'lug',
    'Limburguês': 'lim',
    'Lingala': 'lin',
    'Lao': 'lao',
    'Lituano': 'lit',
    'Luba-Katanga': 'lub',
    'Letão': 'lav',
    'Manx': 'glv',
    'Macedônio': 'mkd',
    'Malgaxe': 'mlg',
    'Malaio': 'msa',
    'Malayalam': 'mal',
    'Maltês': 'mlt',
    'Maori': 'mri',
    'Marathi': 'mar',
    'Marshalês': 'mah',
    'Mongol': 'mon',
    'Nauru': 'nau',
    'Navajo': 'nav',
    'Bokmål norueguês': 'nob',
    'Ndebele do Norte': 'nde',
    'Nepali': 'nep',
    'Ndonga': 'ndo',
    'Norueguês Nynorsk': 'nno',
    'Norueguês': 'nor',
    'Nuosu': 'iii',
    'Ndebele do Sul': 'nbl',
    'Ossétio': 'oci',
    'Ojibua': 'oji',
    'Oromo': 'orm',
    'Oriá': 'ori',
    'Osseta': 'oss',
    'Panjabi': 'pan',
    'Pāli': 'pli',
    'Persa': 'fas',
    'Polonês': 'pol',
    'Pachto': 'pus',
    'Quechua': 'que',
    'Romanche': 'roh',
    'Kirundi': 'run',
    'Romeno': 'ron',
    'Russo': 'rus',
    'Sânscrito': 'san',
    'Sardo': 'srd',
    'Sindi': 'snd',
    'Sami do Norte': 'sme',
    'Samoano': 'smo',
    'Sango': 'sag',
    'Sérvio': 'srp',
    'Gaélico': 'gla',
    'Shona': 'sna',
    'Cingalês': 'sin',
    'Eslovaco': 'slk',
    'Esloveno': 'slv',
    'Somali': 'som',
    'Southern Sotho': 'sot',
    'Sundanês': 'sun',
    'Suaíli': 'swa',
    'Suazi': 'ssw',
    'Sueco': 'swe',
    'Tâmil': 'tam',
    'Telugu': 'tel',
    'Tajique': 'tgk',
    'Tailandês': 'tha',
    'Tigrínia': 'tir',
    'Tibetano': 'bod',
    'Turcomeno': 'tuk',
    'Tagalog': 'tgl',
    'Tsuana': 'tsn',
    'Tonga': 'ton',
    'Turco': 'tur',
    'Tsonga': 'tso',
    'Tatar': 'tat',
    'Twi': 'twi',
    'Taitiano': 'tah',
    'Uigur': 'uig',
    'Ucraniano': 'ukr',
    'Urdu': 'urd',
    'Uzbeque': 'uzb',
    'Venda': 'ven',
    'Vietnamita': 'vie',
    'Volapük': 'vol',
    'Valão': 'wln',
    'Galês': 'cym',
    'Wolof': 'wol',
    'Frísio ocidental': 'fry',
    'Xhosa': 'xho',
    'Iídiche': 'yid',
    'Iorubá': 'yor',
    'Zhuang, Chuang': 'zha',
    'Zulu': 'zul'
}
